@@ -12,10 +12,13 @@ class RealtimeX:
         
         url = self._build_url()
         self.connection = Connection(url)
-        
-        self.connection.bind('message', self._handle_message)
+        self._setup_connection_handlers()
         self.connection.connect()
 
+    def _setup_connection_handlers(self) -> None:
+        # Route server-event messages to channels
+        self.connection.bind('message', self._route_to_channel)
+
     def subscribe(self, channel_name: str) -> Channel:
         if channel_name in self.channels:
             return self.channels[channel_name]
@@ -23,7 +26,11 @@ class RealtimeX:
         channel = Channel(channel_name, self)
         self.channels[channel_name] = channel
 
-        self.connection.send('realtimex:subscribe', {'channel': channel_name})
+        # Send subscribe event like JS SDK
+        self.connection.send({
+            'event': 'subscribe',
+            'data': {'channel': channel_name}
+        })
         
         return channel
 
@@ -31,7 +38,11 @@ class RealtimeX:
         if channel_name not in self.channels:
             return
 
-        self.connection.send('realtimex:unsubscribe', {'channel': channel_name})
+        # Send unsubscribe event like JS SDK
+        self.connection.send({
+            'event': 'unsubscribe',
+            'data': {'channel': channel_name}
+        })
         del self.channels[channel_name]
 
     def disconnect(self) -> None:
@@ -54,30 +65,11 @@ class RealtimeX:
         
         return f"{protocol}://{host}:{port}?api_key={self.api_key}"
 
-    def _handle_message(self, message: Dict) -> None:
-        event = message.get('event')
-        data = message.get('data', {})
+    def _route_to_channel(self, message: Dict) -> None:
+        # Route server-event to appropriate channel
+        channel_name = message.get('channel')
+        event_name = message.get('event')
+        event_data = message.get('data')
         
-        if event == 'server-event':
-            channel_name = data.get('channel')
-            event_name = data.get('event')
-            event_data = data.get('data')
-            
-            if channel_name in self.channels:
-                self.channels[channel_name]._handle_event(event_name, event_data)
-        
-        elif event == 'realtimex_internal:subscription_succeeded':
-            channel_name = data.get('channel')
-            # Emit on connection (like JS SDK)
-            self.connection.emit('subscription_succeeded', data)
-            # Also emit on channel
-            if channel_name in self.channels:
-                self.channels[channel_name].emit('realtimex_internal:subscription_succeeded', data)
-        
-        elif event == 'realtimex_internal:subscription_error':
-            channel_name = data.get('channel')
-            # Emit on connection (like JS SDK)
-            self.connection.emit('subscription_error', data)
-            # Also emit on channel
-            if channel_name in self.channels:
-                self.channels[channel_name].emit('realtimex_internal:subscription_error', data)
+        if channel_name and channel_name in self.channels:
+            self.channels[channel_name]._handle_event(event_name, event_data)
